API docs for “spamfighter.core.firewall.DoFirewallStatement”

# Class s.c.f.DoFirewallStatement(FirewallStatement):

Part of spamfighter.core.firewall View Source View In Hierarchy

Реализация правила "do ... mark as ..."

Instance Variables | func | частично определенный вызов функции обработки сообщения (type: `func` )
| func_name | имя вызываемого правила (type: `str` )
| func_args | аргументы правила (type: `dict` )
| markers | список тегов, которыми надо пометить сообщение в случае "успешной" обработки (type: `list(str)` )

Method | __init__ | Конструктор.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented
Method | __str__ | Получить строковое представление правила (в исходной грамматике).
Method | compile | Скомпилировать правило, присоединив его к цепочке deferred.
Method | _do_helper |

Inherited from FirewallStatement:

Method | _if_helper | Элемент цепочки отложенных вызовов, отвечающий за обработку условия.
Method | _label_helper | Errback, который ловит `SkipToProcess`, чтобы обеcпечить остановку

def __init__(self, func_name, func_args, markers=None, **kwargs): (source)
overrides spamfighter.core.firewall.FirewallStatement.__init__
Конструктор.

Parameters | func_name | имя вызываемого правила (type: `str` )
| func_args | аргументы правила (type: `dict` )
| markers | теги, которыми надо пометеить сообщение в случае "успешной" обработки (type: `list(str)` )

def __eq__(self, other): (source)
overrides spamfighter.core.firewall.FirewallStatement.__eq__
Undocumented
def __repr__(self): (source)
overrides spamfighter.core.firewall.FirewallStatement.__repr__
Undocumented
def __str__(self): (source)
overrides spamfighter.core.firewall.FirewallStatement.__str__
Получить строковое представление правила (в исходной грамматике).

Returns | (type: `str` )

def compile(self, d, debug=False): (source)
overrides spamfighter.core.firewall.FirewallStatement.compile
Скомпилировать правило, присоединив его к цепочке deferred.

Parameters | d | цепочка отложенных вызовов (type: `twisted.internet.defer.Deferred` )
| debug | включить отладочный режим? (type: `bool` )

def _do_helper(self, pack, debug=False): (source)

Parameters | pack | информация о обрабатываемом сообщении (type: `FirewallMessagePack` )
| debug | включить отладочный режим? (type: `bool` )